@@ -189,6 +189,17 @@ PRESETS: dict[str, ColorProfile] = {
         '#282828'
     ]),
 
+    # xenogender sourced from https://commons.wikimedia.org/wiki/File:Xenogender_pride_flag.svg
+    'xenogender': ColorProfile([
+        '#FF6692',
+        '#FF9A98',
+        '#FFB883',
+        '#FBFFA8',
+        '#85BCFF',
+        '#9D85FF',
+        '#A510FF'
+    ]),
+
     'agender': ColorProfile([
         '#000000',
         '#BABABA',
@@ -499,7 +510,7 @@ PRESETS: dict[str, ColorProfile] = {
         '#740194',
     ]),
 
-    'autoromantic': ColorProfile([ # symbol interpreted
+    'autoromantic': ColorProfile([  # symbol interpreted
         '#99D9EA',
         '#99D9EA',
         '#3DA542',
@@ -519,6 +530,27 @@ PRESETS: dict[str, ColorProfile] = {
         '#5276D4',
     ]).with_weights([1, 1, 1, 1, 1, 5, 5, 5])),
 
+    # sourced from https://commons.wikimedia.org/wiki/File:Girlflux_Pride_Flag.jpg
+    "girlflux": ColorProfile([
+        "f9e6d7",
+        "f2526c",
+        "bf0311",
+        "e9c587",
+        "bf0311",
+        "f2526c",
+        "f9e6d7",
+    ]),
+
+    # sourced from https://www.deviantart.com/pride-flags/art/Genderflux-1-543925589
+    "genderflux": ColorProfile([
+        "f47694",
+        "f2a2b9",
+        "cecece",
+        "7ce0f7",
+        "3ecdf9",
+        "fff48d",
+    ]),
+
     "finsexual": ColorProfile([
         "#B18EDF",
         "#D7B1E2",
@@ -526,7 +558,7 @@ PRESETS: dict[str, ColorProfile] = {
         "#F39FCE",
         "#EA7BB3",
     ]),
-    
+
     'unlabeled1': ColorProfile([
         '#EAF8E4',
         '#FDFDFB',
@@ -553,6 +585,16 @@ PRESETS: dict[str, ColorProfile] = {
         '#FFF798',
     ]),
 
+    'pangender.contrast': ColorProfile([
+        '#ffe87f',
+        '#fcbaa6',
+        '#fbc9f3',
+        '#FFFFFF',
+        '#fbc9f3',
+        '#fcbaa6',
+        '#ffe87f',
+    ]),
+
     'gendernonconforming1': ColorProfile(
         ColorProfile([
             '#50284d',
@@ -563,7 +605,7 @@ PRESETS: dict[str, ColorProfile] = {
             '#96467b',
             '#50284d'
         ]).with_weights([
-            4,1,1,1,1,1,4
+            4, 1, 1, 1, 1, 1, 4
         ])
     ),
 
@@ -610,7 +652,7 @@ PRESETS: dict[str, ColorProfile] = {
     ]),
 
     # gendervoid and related flags sourced from: https://gender.fandom.com/wiki/Gendervoid
-    'gendervoid' : ColorProfile([
+    'gendervoid': ColorProfile([
         "#081149",
         "#4B484B",
         "#000000",
@@ -618,7 +660,7 @@ PRESETS: dict[str, ColorProfile] = {
         "#081149"
     ]),
 
-    'voidgirl' : ColorProfile([
+    'voidgirl': ColorProfile([
         "#180827",
         "#7A5A8B",
         "#E09BED",
@@ -626,7 +668,7 @@ PRESETS: dict[str, ColorProfile] = {
         "#180827"
     ]),
 
-    'voidboy' : ColorProfile([
+    'voidboy': ColorProfile([
         "#0B130C",
         "#547655",
         "#66B969",
@@ -635,12 +677,253 @@ PRESETS: dict[str, ColorProfile] = {
     ]),
 
     # used https://twitter.com/foxbrained/status/1667621855518236674/photo/1 as source and colorpicked
-    'nonhuman-unity' : ColorProfile([
+    'nonhuman-unity': ColorProfile([
         "#177B49",
         "#FFFFFF",
         "#593C90"
     ]),
 
+    # used https://pluralpedia.org/w/Plurality#/media/File:Plural-Flag-1.jpg as source and colorpicked
+    'plural': ColorProfile([
+        "#2D0625",
+        "#543475",
+        "#7675C3",
+        "#89C7B0",
+        "#F3EDBD",
+    ]),
+
+    # sampled from https://es.m.wikipedia.org/wiki/Archivo:Fraysexual_flag.jpg
+    'fraysexual': ColorProfile([
+        '#226CB5',
+        '#94E7DD',
+        '#FFFFFF',
+        '#636363',
+    ]),
+
+    # Queer Subcultures
+    # sourced from https://commons.wikimedia.org/wiki/File:Bear_Brotherhood_flag.svg
+    'bear': ColorProfile([
+        '#623804',
+	'#D56300',
+	'#FEDD63',
+	'#FEE6B8',
+	'#FFFFFF',
+	'#555555',
+    ]),
+
+    # colorpicked from https://commons.wikimedia.org/wiki/File:Butch_Flag.png
+    'butch': ColorProfile([
+	'#D72800',
+	'#F17623',
+	'#FF9C56',
+	'#FFFDF6',
+	'#FFCE89',
+	'#FEAF02',
+	'#A37000',
+    ]),
+	
+    # colorpicked from https://commons.wikimedia.org/wiki/File:Leather,_Latex,_and_BDSM_pride_-_Light.svg
+    'leather': ColorProfile([
+	'#000000',
+	'#252580',
+	'#000000',
+	'#252580',
+	'#FFFFFF',
+	'#252580',
+	'#000000',
+	'#252580',
+	'#000000',
+    ]),
+
+    # colorpicked from https://commons.wikimedia.org/wiki/File:Official_Otter_Pride_Flag_by_Bearbackgear.jpg
+    'otter': ColorProfile([
+	'#263881',
+	'#5C9DC9',
+	'#FFFFFF',
+	'#3A291D',
+	'#5C9DC9',
+	'#263881',
+    ]),
+
+    # colorpicked from https://commons.wikimedia.org/wiki/File:Twink_Pride_Flag_(proposed).svg
+    'twink': ColorProfile([
+	'#FFB2FF',
+	'#FFFFFF',
+	'#FFFF81',
+    ]),
+ 
+    'kenochoric': ColorProfile([
+        '#000000',
+        '#2E1569',
+        '#824DB7',
+        '#C7A1D6',
+    ]),
+
+    'veldian': ColorProfile([
+        '#D182A8',
+        '#FAF6E0',
+        '#69ACBE',
+        '#5D448F',
+        '#3A113E',
+    ]),
+
+    'solian': ColorProfile([
+        '#FFF8ED',
+        '#FFE7A8',
+        '#F1B870',
+        '#A56058',
+        '#46281E',
+    ]),
+
+    'lunian': ColorProfile([
+        '#2F0E62',
+        '#6F41B1',
+        '#889FDF',
+        '#7DDFD5',
+        '#D2F2E2',
+    ]),
+
+    # Start of Extras by Jaida Corvera
+    # polyamorous flag colors pulled from https://polyamproud.com/flag
+    'polyam': ColorProfile([
+        "#FFFFFF",
+        "#FCBF00",
+        "#009FE3",
+        "#E50051",
+        "#340C46",
+    ]),
+
+    'sapphic': ColorProfile([
+        "#FD8BA8",
+        "#FBF2FF",
+        "#C76BC5",
+        "#FDD768",
+        "#C76BC5",
+        "#FBF2FF",
+        "#FD8BA8"
+    ]),
+
+    'androgyne': ColorProfile([
+        "#FE007F",
+        "#9832FF",
+        "#00B8E7",
+    ]),
+
+    'interprogress': ColorProfile([
+        "#FFD800",
+        "#7902AA",
+        "#FFFFFF",
+        "#FFAFC8",
+        "#74D7EE",
+        "#613915",
+        "#000000",
+        '#E50000',
+        '#FF8D00',
+        '#FFEE00',
+        '#028121',
+        '#004CFF',
+        '#770088'
+    ]),
+
+    'progress': ColorProfile([
+        "#FFFFFF",
+        "#FFAFC8",
+        "#74D7EE",
+        "#613915",
+        "#000000",
+        '#E50000',
+        '#FF8D00',
+        '#FFEE00',
+        '#028121',
+        '#004CFF',
+        '#770088'
+    ]),
+
+    'intersex': ColorProfile([
+        "#FFD800",
+        "#FFD800",
+        "#7902AA",
+        "#FFD800",
+        "#FFD800"
+    ]),
+
+    'old-polyam': ColorProfile([
+        "#0000FF",
+        "#FF0000",
+        "#FFFF00",
+        "#FF0000",
+        "#000000"
+    ]),
+
+    'equal-rights': ColorProfile([
+        "#0000FF",
+        "#0000FF",
+        "#FFFF00",
+        "#0000FF",
+        "#0000FF",
+        "#FFFF00",
+        "#0000FF",
+        "#0000FF"
+    ]),
+
+    'drag': ColorProfile([
+        "#CC67FF",
+        "#FFFFFF",
+        "#FFA3E3",
+        "#FFFFFF",
+        "#3366FF"
+    ]),
+
+    # Pronoun Flags
+
+    'pronounfluid': ColorProfile([
+        "#ffb3f9",
+        "#ffffff",
+        "#d1fdcb",
+        "#c7b0ff",
+        "#000000",
+        "#b8ccff"
+    ]),
+
+    'pronounflux': ColorProfile([
+        "#fdb3f8",
+        "#b6ccfa",
+        "#18ddd3",
+        "#64ff89",
+        "#ff7690",
+        "#ffffff"
+    ]),
+
+    'exipronoun': ColorProfile([
+        "#1c3d34",
+        "#ffffff",
+        "#321848",
+        "#000000"
+    ]),
+
+    'neopronoun': ColorProfile([
+        "#bcec64",
+        "#ffffff",
+        "#38077a"
+    ]),
+
+    'neofluid': ColorProfile([
+        "#ffeca0",
+        "#ffffff",
+        "#ffeca0",
+        "#38087a",
+        "#bcec64"
+    ]),
+
+    'genderqueer': ColorProfile([
+        "#b57edc",
+        "#b57edc",
+        "#ffffff",
+        "#ffffff",
+        "#4a8123",
+        "#4a8123"
+    ]),
+
     # Meme flags
     'beiyang': ColorProfile([
         '#DF1B12',
@@ -657,4 +940,28 @@ PRESETS: dict[str, ColorProfile] = {
         '#7D3829',
         '#F3A26A',
     ]),
+
+    # colors from Gilbert Baker's original 1978 flag design
+    # used https://gilbertbaker.com/rainbow-flag-color-meanings/ as source and colorpicked
+    'baker': ColorProfile([
+        '#F23D9E',
+        '#F80A24',
+        '#F78022',
+        '#F9E81F',
+        '#1E972E',
+        '#1B86BC',
+        '#243897',
+        '#6F0A82',
+    ]),
+
+    # this is 4 all the dogs, from zombpawcoins on tumblr!
+    'caninekin': ColorProfile([
+        '#2d2822',
+        '#543d25',
+        '#9c754d',
+        '#e8dac2',
+        '#cfad8c',
+        '#b77b55',
+        '#954e31'
+    ])
 }
